==> piwigo-2.5.3.zip: piwigo/language/en_GB/admin.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based photo gallery                                    |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2013 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+



$lang['(this tag will be deleted)'] = '(this keyword will be deleted)';
$lang['Add a criteria'] = 'Add a criterion';
$lang['add new photos to caddie'] = "add new photos to collection";
$lang['Add to caddie'] = "Add to collection";
$lang['albums added in the database'] = "albums added to the database";
$lang['Albums authorized thanks to group associations'] = "Albums authorised by group association";
$lang['All optimizations have been successfully completed.'] = "All optimisations have been successfully completed.";
$lang['Allow user customization'] = 'Allow user customisation';
$lang['Are you sure to install this upgrade? You must verify if this version does not need uninstallation.'] = "Are you sure you want to install this upgrade? You must check if this version needs prior uninstallation.";
$lang['Authorize users to add comments on selected albums'] = "Authorise users to add comments on selected albums";
$lang['Authorized'] = "Authorised";
$lang['Caddie management'] = "Collection management";
$lang['Caddie'] = "Collection";
$lang['Complementary mail content'] = "Extra mail content";
$lang['Database synchronization with files'] = 'Database synchronisation with files';
$lang['Does not represent'] = "Is not thumbnail for";
$lang['Duplicate selected tags'] = 'Duplicate selected keywords';
$lang['Edit selected tags'] = "Edit selected keywords";
$lang['Edit tags'] = "Edit keyword";
$lang['Errors caption'] = "Error legend";
$lang['errors during synchronization'] = "errors during synchronisation";
$lang['even already synchronized photos'] = "including already synchronised photos";
$lang['Execution time is out, treatment must be continue [Estimated time: %d seconds].'] = "Permitted execution time exceeded, operation will continue [Estimated time: %d seconds].";
$lang['Following plugins may not be compatible with the new version of Piwigo:'] = 'The following plugins may not be compatible with the new version of Piwigo:';
$lang['Following themes may not be compatible with the new version of Piwigo:'] = 'The following themes may not be compatible with the new version of Piwigo:';
$lang['FTP + Synchronization'] = 'FTP + Synchronisation';
$lang['Group management'] = "Group management";
$lang['I decide to update anyway'] = 'I choose to update anyway';
$lang['Impossible to delete this theme. Other themes depends on it: %s'] = 'This theme cannot be deleted, because other themes depend on it: %s';
$lang['Instructions to use Piwigo'] = "How to use Piwigo";
$lang['Last hit'] = "Latest hit";
$lang['Last import'] = 'Latest import';
$lang['Last revisions'] = "Latest revisions";
$lang['Last send'] = "Latest send";
$lang['Link all album photos to some existing albums'] = "Link all album photos to some existing album";
$lang['Manage tags'] = 'Manage keywords';
$lang['Manage the members'] = 'Manage members';
$lang['Merge selected tags'] = 'Merge selected keywords';
$lang['Merge tags'] = 'Merge keywords';
$lang['Metadata synchronization results'] = "Metadata synchronisation results";
$lang['Metadata synchronized from file'] = "Metadata synchronised from file";
$lang['only perform a simulation (no change in database will be made)'] = "perform a simulation only (nothing will be changed in the database)";
$lang['Operation in progress'] = 'Operation in progress.';
$lang['Optimizations have been completed with some errors.'] = "Optimisations have been completed with some errors.";
$lang['Orphan tags deleted'] = 'Orphan keywords deleted';
$lang['Photo informations updated'] = "Photo information updated";
$lang['photos added in the database'] = "photos added to the database";
$lang['photos candidates for metadata synchronization'] = "candidate photos for metadata synchronisation";
$lang['photos informations synchronized with files metadata'] = "photo information synchronised with file metadata";
$lang['Purge never used notification feeds'] = "Purge unused notification feeds";
$lang['Quick Local Synchronization'] = "Quick Local Synchronisation";
$lang['reduce to single existing albums'] = "reduce to single existing album";
$lang['Reinitialize check integrity'] = "Reinitialise integrity check";
$lang['Remove from caddie'] = 'Remove from collection';
$lang['remove tags'] = 'Remove keywords';
$lang['Repair and optimize database'] = "Repair and optimise database";
$lang['Replacement of original templates by customized templates from template-extension subfolder'] = "Replacement of original templates by customised templates from the template-extension subfolder";
$lang['Replacers (customized templates)'] = "Substitutes (customised templates)";
$lang['Select at least two tags for merging'] = 'Select at least two keywords for merging';
$lang['Subscribers could be listed (available) only if there is new elements to notify.'] = "Subscribers listed (available) only if there are new elements to notify.";
$lang['synchronize files metadata with database photos informations'] = "synchronise database photos with file metadata";
$lang['synchronize files structure with database'] = "synchronise file structure with database";
$lang['Synchronize metadata'] = "Synchronise metadata";
$lang['Synchronize'] = "Synchronise";
$lang['Tag "%s" already exists'] = "Keyword \"%s\" already exists";
$lang['Tag "%s" is now a duplicate of "%s"'] = "Keyword \"%s\" is now a duplicate of \"%s\"";
$lang['Tag "%s" was added'] = "Keyword \"%s\" has been added";
$lang['Tag selection'] = "Keyword selection";
$lang['Tags <em>%s</em> merged into tag <em>%s</em>'] = 'Keywords <em>%s</em> merged into keyword <em>%s</em>';
$lang['The %d following tags were deleted'] = "The following %d keywords have been deleted";
$lang['The anomaly will be ignored until next application version'] = "The anomaly will be ignored until the next version of the application";
$lang['The following tag was deleted'] = 'The following keyword was deleted';
$lang['The number of comments a page must be between 5 and 50 included.'] = "The number of comments on a page must be between 5 and 50 inclusive.";
$lang['The webmaster has subscribed you to receiving notifications by mail.'] = "The webmaster has added you to the mail notification list.";
$lang['The webmaster has unsubscribed you from receiving notifications by mail.'] = "The webmaster has removed you from the list for receiving notifications by mail.";
$lang['There is no available subscribers to mail.'] = "There are no subscribers to be notified by mail.";
$lang['Thumbnails generation in progress...'] = 'Thumbnail generation in progress...';
$lang['Time to send mail is limited. Others mails are skipped.'] = "The maximum time for sending mail has been exceeded. Remaining emails have been skipped.";
$lang['Update albums informations'] = "Update album information";
$lang['Update photos information'] = "Update photo information";
$lang['User list'] = "User list";
$lang['Virtual albums to move'] = "Virtual albums to be moved";
$lang['With no tag'] = 'With no keyword';
$lang['You are running on development sources, no check possible.'] = "You are running a development version, no check possible.";
$lang['You have specified <i>$conf[\'order_by\']</i> in your local configuration file, this parameter in deprecated, please remove it or rename it into <i>$conf[\'order_by_custom\']</i> !'] = 'You have specified <i>$conf[\'order_by\']</i> in your local configuration file, this parameter is deprecated, please remove it or rename it to <i>$conf[\'order_by_custom\']</i> !';
$lang['You need to upgrade your system to take full advantage of the application else the application will not work correctly, or not at all'] = "Please upgrade your system to take full advantage of the application, otherwise it might work improperly, or not at all";

$lang['digiKam is designed for photographers who want to view, manage, edit, enhance, organize, tag, and share photographs.'] = 'digiKam is designed for photographers who want to view, manage, edit, enhance, organise, tag, and share photographs.';
$lang['You have %d orphan tags: %s.'] = 'You have %d orphan keywords: %s.';
$lang['Source tag'] = 'Source keyword';
$lang['Select the destination tag'] = 'Select the destination keyword';
$lang['Select at least one tag'] = 'Select at least one keyword';
$lang['No destination tag selected'] = 'No destination keyword selected';
$lang['New tag'] = 'New Keyword';
$lang['Delete orphan tags'] = 'Delete orphan keywords';
$lang['Delete selected tags'] = 'Deleted selected keywords';
$lang['Add tags'] = 'Add keywords';
$lang['Add a tag'] = 'Add a keyword';
$lang['%d albums including'] = '%d albums included';
$lang['%d album including'] = '%d album included';
?>

==> piwigo-2.9.3.zip: piwigo/language/en_GB/admin.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based photo gallery                                    |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2016 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+



$lang['(this tag will be deleted)'] = '(this keyword will be deleted)';
$lang['Add a criteria'] = 'Add a criterion';
$lang['add new photos to caddie'] = 'add new photos to basket';
$lang['Add to caddie'] = 'Add to basket';
$lang['albums added in the database'] = "albums added to the database";
$lang['Albums authorized thanks to group associations'] = "Albums authorised by group association";
$lang['All optimizations have been successfully completed.'] = "All optimisations have been successfully completed.";
$lang['Allow user customization'] = 'Allow user customisation';
$lang['Are you sure to install this upgrade? You must verify if this version does not need uninstallation.'] = "Are you sure you want to install this upgrade? You must check if this version needs prior uninstallation.";
$lang['Authorize users to add comments on selected albums'] = "Authorise users to add comments on selected albums";
$lang['Authorized'] = "Authorised";
$lang['Caddie management'] = 'Basket management';
$lang['Caddie'] = 'Basket';
$lang['Complementary mail content'] = "Extra mail content";
$lang['Database synchronization with files'] = 'Database synchronisation with files';
$lang['Does not represent'] = "Is not thumbnail for";
$lang['Duplicate selected tags'] = 'Duplicate selected keywords';
$lang['Edit selected tags'] = "Edit selected keywords";
$lang['Edit tags'] = "Edit keyword";
$lang['Errors caption'] = "Error legend";
$lang['errors during synchronization'] = "errors during synchronisation";
$lang['even already synchronized photos'] = "including already synchronised photos";
$lang['Execution time is out, treatment must be continue [Estimated time: %d seconds].'] = "Permitted execution time exceeded, operation will continue [Estimated time: %d seconds].";
$lang['Following plugins may not be compatible with the new version of Piwigo:'] = 'The following plugins may not be compatible with the new version of Piwigo:';
$lang['Following themes may not be compatible with the new version of Piwigo:'] = 'The following themes may not be compatible with the new version of Piwigo:';
$lang['FTP + Synchronization'] = 'FTP + Synchronisation';
$lang['Group management'] = "Group management";
$lang['I decide to update anyway'] = 'I choose to update anyway';
$lang['Impossible to delete this theme. Other themes depends on it: %s'] = 'This theme cannot be deleted because other themes depend on it: %s';
$lang['Instructions to use Piwigo'] = "How to use Piwigo";
$lang['Last hit'] = "Latest hit";
$lang['Last import'] = 'Latest import';
$lang['Last revisions'] = "Latest revisions";
$lang['Last send'] = 'Last sent';
$lang['Link all album photos to some existing albums'] = "Link all album photos to some existing album";
$lang['Manage tags'] = 'Manage keywords';
$lang['Manage the members'] = 'Manage members';
$lang['Merge selected tags'] = 'Merge selected keywords';
$lang['Merge tags'] = 'Merge keywords';
$lang['Metadata synchronization results'] = "Metadata synchronisation results";
$lang['Metadata synchronized from file'] = "Metadata synchronised from file";
$lang['only perform a simulation (no change in database will be made)'] = "perform a simulation only (nothing will be changed in the database)";
$lang['Operation in progress'] = 'Operation in progress.';
$lang['Optimizations have been completed with some errors.'] = "Optimisations have been completed with some errors.";
$lang['Orphan tags deleted'] = 'Orphan keywords deleted';
$lang['Photo informations updated'] = "Photo information updated";
$lang['photos added in the database'] = "photos added to the database";
$lang['photos candidates for metadata synchronization'] = "candidate photos for metadata synchronisation";
$lang['photos informations synchronized with files metadata'] = "photo information synchronised with file metadata";
$lang['Purge never used notification feeds'] = "Purge unused notification feeds";
$lang['Quick Local Synchronization'] = 'Quick local synchronisation';
$lang['reduce to single existing albums'] = "reduce to single existing album";
$lang['Reinitialize check integrity'] = "Reinitialise integrity check";
$lang['Remove from caddie'] = 'Remove from basket';
$lang['remove tags'] = 'Remove keywords';
$lang['Repair and optimize database'] = "Repair and optimise database";
$lang['Replacement of original templates by customized templates from template-extension subfolder'] = "Replacement of original templates by customised templates from the template-extension subfolder";
$lang['Replacers (customized templates)'] = "Substitutes (customised templates)";
$lang['Select at least two tags for merging'] = 'Select at least two keywords for merging';
$lang['Subscribers could be listed (available) only if there is new elements to notify.'] = "Subscribers listed (available) only if there are new elements to notify.";
$lang['synchronize files metadata with database photos informations'] = "synchronise database photos with file metadata";
$lang['synchronize files structure with database'] = "synchronise file structure with database";
$lang['Synchronize metadata'] = "Synchronise metadata";
$lang['Synchronize'] = "Synchronise";
$lang['Tag "%s" already exists'] = "Keyword \"%s\" already exists";
$lang['Tag "%s" is now a duplicate of "%s"'] = "Keyword \"%s\" is now a duplicate of \"%s\"";
$lang['Tag "%s" was added'] = "Keyword \"%s\" has been added";
$lang['Tag selection'] = "Keyword selection";
$lang['Tags <em>%s</em> merged into tag <em>%s</em>'] = 'Keywords <em>%s</em> merged into keyword <em>%s</em>';
$lang['The %d following tags were deleted'] = "The following %d keywords have been deleted";
$lang['The anomaly will be ignored until next application version'] = "The anomaly will be ignored until the next version of the application";
$lang['The following tag was deleted'] = 'The following keyword was deleted';
$lang['The number of comments a page must be between 5 and 50 included.'] = "The number of comments on a page must be between 5 and 50 inclusive.";
$lang['The webmaster has subscribed you to receiving notifications by mail.'] = "The webmaster has added you to the mail notification list.";
$lang['The webmaster has unsubscribed you from receiving notifications by mail.'] = "The webmaster has removed you from the list for receiving notifications by mail.";
$lang['There is no available subscribers to mail.'] = "There are no subscribers to be notified by mail.";
$lang['Thumbnails generation in progress...'] = 'Thumbnail generation in progress...';
$lang['Time to send mail is limited. Others mails are skipped.'] = "The maximum time for sending mail has been exceeded. Remaining emails have been skipped.";
$lang['Update albums informations'] = "Update album information";
$lang['Update photos information'] = "Update photo information";
$lang['User list'] = "User list";
$lang['Virtual albums to move'] = "Virtual albums to be moved";
$lang['With no tag'] = 'With no keyword';
$lang['You are running on development sources, no check possible.'] = "You are running a development version, no check possible.";
$lang['You have specified <i>$conf[\'order_by\']</i> in your local configuration file, this parameter in deprecated, please remove it or rename it into <i>$conf[\'order_by_custom\']</i> !'] = 'You have specified <i>$conf[\'order_by\']</i> in your local configuration file, this parameter is deprecated, please remove it or rename it to <i>$conf[\'order_by_custom\']</i> !';
$lang['You need to upgrade your system to take full advantage of the application else the application will not work correctly, or not at all'] = 'Please upgrade your system to take full advantage of the application, otherwise it might not work correctly, or not at all';

$lang['digiKam is designed for photographers who want to view, manage, edit, enhance, organize, tag, and share photographs.'] = 'digiKam is designed for photographers who want to view, manage, edit, enhance, organise, tag, and share photographs.';
$lang['You have %d orphan tags: %s.'] = 'You have %d orphan keywords: %s.';
$lang['Source tag'] = 'Source keyword';
$lang['Select the destination tag'] = 'Select the destination keyword';
$lang['Select at least one tag'] = 'Select at least one keyword';
$lang['No destination tag selected'] = 'No destination keyword selected';
$lang['New tag'] = 'New keyword';
$lang['Delete orphan tags'] = 'Delete orphan keywords';
$lang['Delete selected tags'] = 'Deleted selected keywords';
$lang['Add tags'] = 'Add keywords';
$lang['Add a tag'] = 'Add a keyword';
$lang['%d albums including'] = '%d albums included';
$lang['%d album including'] = '%d album included';
$lang['The Piwigo publish Plug-in allows you to export and synchronize photos from Lightroom directly to your Piwigo photo gallery.'] = 'The Piwigo publish Plug-in allows you to export and synchronise photos from Lightroom directly to your Piwigo photo gallery.';
$lang['Shotwell is an open source digital photo organizer that runs on Linux. It is the default photo manager in Ubuntu and Fedora.'] = 'Shotwell is an open source digital photo organiser that runs on Linux. It is the default photo manager in Ubuntu and Fedora.';
$lang['Select a zone with your mouse to define a new center of interest.'] = 'Select a zone with your mouse to define a new centre of interest.';
$lang['Save Settings'] = 'Save settings';
$lang['Read Piwigo Documentation'] = 'Read Piwigo documentation';
$lang['New Version'] = 'New version';
$lang['Missing Plugins'] = 'Missing plugins';
$lang['Manage Permissions'] = 'Manage permissions';
$lang['Manage authorizations for selected albums'] = 'Manage authorisations for selected albums';
$lang['Installed Languages'] = 'Installed languages';
$lang['Installed Themes'] = 'Installed themes';
$lang['Inactive Languages'] = 'Inactive languages';
$lang['Inactive Plugins'] = 'Inactive plugins';
$lang['Ignore All'] = 'Ignore all';
$lang['Follow Orientation'] = 'Follow orientation ';
$lang['Dump Database'] = 'Dump database';
$lang['Center of interest'] = 'Centre of interest';
$lang['By default, the center of interest is placed in the middle of the photo.'] = 'By default, the centre of interest is placed in the middle of the photo.';
$lang['Active Themes'] = 'Active themes';
$lang['Add New Language'] = 'Add a new language';
$lang['Active Languages'] = 'Active languages';
$lang['Active Plugins'] = 'Active plugins';
$lang['You are using the Flash uploader. Problems? Try the <a href="%s">Browser uploader</a> instead.'] = 'You are using the Flash uploader.  Problems? Try the <a href="%s">Browser uploader</a> instead.';
$lang['Upload Photos'] = 'Upload photos';
$lang['Uploaded Photos'] = 'Uploaded photos';
$lang['Update All'] = 'Update all';
$lang['Update Complete'] = 'Update complete';
$lang['Switch to clear or dark colors for administration'] = 'Switch to clear or dark colours for administration';
$lang['Start Upload'] = 'Start upload';
$lang['Pending Comments'] = 'Pending comments';
$lang['Obsolete Plugins'] = 'Obsolete plugins';
$lang['Multiple Size'] = 'Multiple size';
$lang['Impossible to activate this theme, the parent theme is missing: %s'] = 'This theme could not be activated  as the parent theme ( %s )is missing';
$lang['Help Me'] = 'Help me';
$lang['An error occured during extraction (%s).'] = 'An error occurred during the files (%s) extraction.';
$lang['An error has occured during upgrade.'] = 'An error has occurred during upgrade.';
$lang['An error has occured during extract. Please check files permissions of your piwigo installation.<br><a href="%s">Click here to show log error</a>.'] = 'An error has occurred during extract. Please check file permissions of your Piwigo installation.<br><a href="%s">Click here to show log error</a>.';
$lang['Empty caddie'] = 'Empty basket';
$lang[' and %d virtual'] = ' and %d virtual';
$lang[' and %d virtuals'] = ' and %d virtual';
$lang['%d album moved'] = '%d album moved';
$lang['%d albums moved'] = '%d albums moved';
$lang['%d anomalies have been detected corrected.'] = '%d anomalies have been detected and corrected.';
$lang['%d anomalies have been detected.'] = '%d anomalies have been detected.';
$lang['%d anomalies have been ignored.'] = '%d anomalies have been ignored.';
$lang['%d anomalies have not been corrected.'] = '%d anomalies have not been corrected.';
$lang['%d anomaly has been corrected.'] = '%d anomaly has been corrected.';
$lang['%d anomaly has been detected.'] = '%d anomaly has been detected.';
$lang['%d anomaly has been ignored.'] = '%d anomaly has been ignored.';
$lang['%d anomaly has not been corrected.'] = '%d anomaly has not been corrected.';
$lang['%d association'] = '%d association';
$lang['%d associations'] = '%d associations';
$lang['%d day'] = '%d day';
$lang['%d days'] = '%d days';
$lang['%d group'] = '%d group';
$lang['%d groups'] = '%d groups';
$lang['%d guest'] = '%d guest';
$lang['%d guests'] = '%d guests';
$lang['%d hour'] = '%d hour';
$lang['%d hours'] = '%d hours';
$lang['%d line filtered'] = '%d line filtered';
$lang['%d lines filtered'] = '%d lines filtered';
$lang['%d mail was not sent.'] = '%d mail has not been sent.';
$lang['%d mail was sent.'] = '%d mail has been sent.';
$lang['%d mails were not sent.'] = '%d mails have not been sent.';
$lang['%d mails were sent.'] = '%d mails have been sent.';
$lang['%d member'] = '%d member';
$lang['%d members'] = '%d members';
$lang['%d minute'] = '%d minute';
$lang['%d minutes'] = '%d minutes';
$lang['%d month'] = '%d month';
$lang['%d months'] = '%d months';
$lang['%d of %d photos selected'] = '%d of %d photos selected';
$lang['%d of %d users selected'] = '%d of %d users selected';
$lang['%d parameter was updated.'] = '%d parameter updated.';
$lang['%d parameters were updated.'] = '%d parameters updated.';
$lang['%d photo was deleted'] = '%d photo deleted';
$lang['%d photos uploaded'] = '%d photos uploaded';
